---
title: "Project Jarāʾid source files"
subtitle: "Readme"
author:
  - Till Grallert
  - Adam Mestyan
date: 2020-12-23
---

Project Jarāʾid aims at providing a bibliography of all periodicals published in Arabic or in Arabic and additional languages between the beginning of the periodical press in the Eastern Mediterranean and 1929 (For a full documentation of the project, see the TEI XML master file). This repository holds the dataset for Project Jarāʾid. The dataset has been published as continuously updated static websites. First, at <https://www.zmo.de/jaraid/> in 2012 and since 2016 at <https://projectjaraid.github.io>. The interface continuous to evolve at the latter URL.

This repository contains the following folders and files

- `authority-files/`: authority files for persons, organisations, and places.
  + `jaraid_authority-file.TEIP5.xml`
- `tei/`: master files of the data set
  + `jaraid_master.TEIP5.xml`: this is the master file, holding the entire data set.
  + `jaraid_master-biblStruct.TEIP5.xml`: this is a computationally generated derivate of the master file.


# Data models
## `jaraid_master.TEIP5.xml`

Currently all data is kept in a single TEI XML file  with prose sections for the introduction and glossaries. Bibliographic information on individual periodicals is recorded in tabular form. Documentation of changes within the source file is patchy since we have mostly relied on GitHub commits to document changes.

The data structure for each row in the table has historical reasons. It is as follows and can be copied in order to add information to the table:

```xml
<row xml:id="t1rxxx" n="xxx" role="data">
    <cell n="1">
     <date when="yyyy or yyyy-mm-dd">Year of first issue</date>
    </cell>
    <cell n="2">month/day of the first issue</cell>
    <cell n="3"><date when="yyyy or yyyy-mm-dd">date of last issue</date></cell>
    <cell n="4">
     <name>title of the periodical</name>
    </cell>
    <cell n="5">
     <placeName>place of publication</placeName>
    </cell>
    <cell n="6">
     <persName>name of publisher etc.</persName>
    </cell>
    <cell n="7">comments</cell>
    <cell n="8">source</cell>
    <cell n="9">holding institutions</cell>
    <cell n="10" xml:lang="ar">عنوان</cell>
    <cell n="11" xml:lang="ar">محرر/رئيس الادارة/صاحب الجورنال</cell>
    <cell n="12" xml:lang="ar">أماكن</cell>
</row>
```

Notes:
- new rows should be added at the bottom of the existing table.
- The `@n` attribute on `<row>` can be omitted and will later be added automatically.
- The `@xml:id` attribute is generated by incrementing the value of the last row of the table, i.e. if the last row has `@xml:id="t1r850"` the new row should be `@xml:id="t1r851"`
- Columns `@n="11"` and `@n="12"` are automatically populated through XSLT by looking up values from the authority file.
- the value of the `@xml:lang` attributes in rows `@n="1"` to `@n="9"` is mostly generic and should not yet be used for reliably retrieving data.

- exemplary entry for the newspaper *al-Iqbāl*

    ```xml
<row n="2341" resp="#pAM" role="data" xml:id="t1r2353" xml:lang="und-Latn">
    <cell n="1"> <date when="1902-04-09" xml:lang="und-Latn">1902</date> </cell>
    <cell n="2" xml:lang="und-Latn">April/9</cell>
    <cell n="3"/>
    <cell n="4" xml:lang="und-Latn"> <name xml:lang="und-Latn">Al-Iqbāl</name> </cell>
    <cell n="5" xml:lang="und-Latn"> <placeName change="#d6e936" ref="jaraid:place:2" xml:lang="und-Latn">Beirut</placeName> </cell>
    <cell n="6" xml:lang="und-Latn"> <persName ref="jaraid:pers:1926" xml:lang="und-Latn">ʿAbd al-Bāsiṭ al-Unsī</persName> </cell>
    <cell n="7" xml:lang="und-Latn"><rs ref="#agt" xml:lang="und-Latn">Ṭ</rs>: school journal</cell>
    <cell n="8" xml:lang="und-Latn"> <rs ref="#agt" xml:lang="und-Latn">Ṭ</rs> </cell>
    <cell n="9" xml:lang="und-Latn"><rs ref="#hCRL" xml:lang="und-Latn">CRL</rs>:<ref resp="AM" target="https://gpa.eastview.com/crl/mena/newspapers/aliq" xml:lang="und-Latn"
     >online 1902-1909</ref></cell>
    <cell change="#d2e947" n="10"> <title level="j" xml:lang="ar">الاقبال</title> </cell>
    <cell n="11"><persName ref="jaraid:pers:1926" xml:lang="ar">عبد الباسط الانسي</persName></cell>
    <cell n="12"><placeName ref="jaraid:place:2" xml:lang="ar">بيروت</placeName></cell>
</row>
    ```

## `jaraid_master-biblStruct.TEIP5.xml`

This file is computationally generated and serialises each row of the `<table>` with the bibliographic information in `jaraid_master.TEIP5.xml` as a `<biblStruct>`. Columns 7 to 9 have been modelled as typed `<note>` children.

- exemplary entry for the newspaper *al-Iqbāl*

    ```xml
<biblStruct resp="#pAM" type="periodical" xml:id="biblStruct_t1r2353">
  <monogr>
     <title level="j" xml:lang="ar-Latn-x-ijmes">Al-Iqbāl</title>
     <title level="j" xml:lang="ar">الاقبال</title>
     <idno type="jaraid">t1r2353</idno>
     <textLang mainLang="ar"/>
     <editor>
        <persName ref="jaraid:pers:1926" xml:lang="und-Latn">ʿAbd al-Bāsiṭ al-Unsī</persName>
     </editor>
     <imprint>
        <pubPlace>
           <placeName ref="jaraid:place:2" xml:lang="und-Latn">Beirut</placeName>
        </pubPlace>
        <date type="onset" when="1902-04-09" xml:lang="und-Latn">1902</date>
     </imprint>
  </monogr>
  <note type="comment"> <rs ref="#agt" xml:lang="und-Latn">Ṭ</rs>: school journal</note>
  <note type="sources">
     <list>
        <item>
           <rs ref="#agt" xml:lang="und-Latn">Ṭ</rs>
        </item>
     </list>
  </note>
  <note type="holdings">
     <list>
        <item>
           <rs ref="#hCRL" xml:lang="und-Latn">CRL</rs>: <ref resp="AM" target="https://gpa.eastview.com/crl/mena/newspapers/aliq" xml:lang="und-Latn">online 1902-1909</ref>
        </item>
     </list>
  </note>
</biblStruct>
    ```
